; $Id: wisard_oifits2data.pro,v 1.7 2007/01/29 16:48:36 meimon Exp $ 
; This file is part of the WISARD software.
;
; Copyright (c) S. Meimon and L. Mugnier, ONERA, 2004-2007.
;
; This software, WISARD, is made of wisard.pro and all the wisard_*.pro files
; under the same directory, as well as the example batch file wisard_batch.pro
; 
; This software is copyright ONERA.
; The authors are Serge Meimon and Laurent Mugnier.
; E-mail: meimon at onera.fr and mugnier at onera.fr
;
; This software is a computer program whose purpose is to reconstruct an image
; of an observed object from a set of interferometric measurements.
;
; This software is governed by the CeCILL-B license under French law and
; abiding by the rules of distribution of free software. You can use, modify
; and/ or redistribute the software under the terms of the CeCILL-B license as
; circulated by CEA, CNRS and INRIA at the following URL
; "http://www.cecill.info".
;
; As a counterpart to the access to the source code and  rights to copy,
; modify and redistribute granted by the license, users are provided only
; with a limited warranty  and the software's author,  the holder of the
; economic rights,  and the successive licensors  have only  limited
; liability. 
;
; In this respect, the user's attention is drawn to the risks associated
; with loading,  using,  modifying and/or developing or reproducing the
; software by the user in light of its specific status of free software,
; that may mean  that it is complicated to manipulate,  and  that  also
; therefore means  that it is reserved for developers  and  experienced
; professionals having in-depth computer knowledge. Users are therefore
; encouraged to load and test the software's suitability as regards their
; requirements in conditions enabling the security of their systems and/or 
; data to be ensured and,  more generally, to use and operate it in the 
; same conditions as regards security. 
;
; The fact that you are presently reading this means that you have had
; knowledge of the CeCILL-B license and that you accept its terms.
;
; Additionally, if you use this code or a code derived from it (e.g., for a
; publication), please cite the following papers, on which it is based:
;   
; (1) S. Meimon, L. M. Mugnier, and G. Le Besnerais,
;   "Reconstruction method for weak-phase optical interferometry", 
;   Opt. Lett., 30(14):1809-1811, July 2005.
;   PDF is on-line at: http://laurent.mugnier.free.fr/publis/Meimon-OL-05.pdf
; (2) S. Meimon, L. M. Mugnier, and Guy Le Besnerais,
;   "A convex approximation of the likelihood in optical interferometry",
;   J. Opt. Soc. Am. A, November 2005.
;   PDF is on-line at: http://laurent.mugnier.free.fr/publis/Meimon-JOSAA-05.pdf
;
;
;+
; NAME:
;	WISARD_OIFITS2OIDATA - Converts oifits data in native data format for WISARD
;
; CATEGORY:
;	Array and Image Processing Routines 
;
; CALLING SEQUENCE:
;	data=WISARD_ONE_OIFITS2DATA( filename[, /VERSION] [, /HELP])
;
;
; PURPOSE:
;   This function converts oifits data in native data format for WISARD
;   quick-and-dirty code to input (some) OIFITS data;
;                        needs some work (anyone interested?)
;
; POSITIONAL PARAMETERS:
;	filename: (input) path of the oifits file to convert
;	
; KEYWORD PARAMETERS:
;   /VERSION : (optional input) prints version number before execution.
;   
;   /HELP    : (optional input) prints the documentation and exits.
;
;
; AUTHORS:
; Serge Meimon and Laurent Mugnier (ONERA). 
; Contact: lastname at onera.fr
;
;
; RESTRICTIONS:
;   This code is copyright (c) S. Meimon and L. Mugnier, ONERA, 2004-2007. 
;   
;   WISARD is governed by the CeCILL-B license under French law and abiding by
;   the rules of distribution of free software. You can use, modify and/ or
;   redistribute the software under the terms of the CeCILL-B license as
;   circulated by CEA, CNRS and INRIA at the following URL:
;   "http://www.cecill.info".
;   See source code for the full notice.
;
;   Additionally, if you use this code or a code derived from it (e.g., for a
;   publication), please cite the following papers, on which it is based:
;   
;   (1) S. Meimon, L. M. Mugnier, and G. Le Besnerais,
;   "Reconstruction method for weak-phase optical interferometry", 
;   Opt. Lett., 30(14):1809-1811, July 2005.
;   PDF is on-line at: http://laurent.mugnier.free.fr/publis/Meimon-OL-05.pdf
;   (2) S. Meimon, L. M. Mugnier, and Guy Le Besnerais,
;   "A convex approximation of the likelihood in optical interferometry",
;   J. Opt. Soc. Am. A, November 2005.
;   PDF is on-line at: http://laurent.mugnier.free.fr/publis/Meimon-JOSAA-05.pdf
;
;
; SEE ALSO:
;   All the WISARD_*.pro files, which are part of WISARD and covered by the
;   same copyright and license.
;   
; HISTORY:
; $Log: wisard_oifits2data.pro,v $
; Revision 1.7  2007/01/29 16:48:36  meimon
; mention du fait que c'est quick and dirty
;
; Revision 1.6  2007/01/29 16:46:59  meimon
; un seul programme au lieu de 2+doc
;
; Revision 1.5  2007/01/09 11:16:40  meimon
; ???
;
; Revision 1.4  2006/11/06 14:58:10  meimon
; !I->!dI
;
; Revision 1.3  2006/11/06 14:55:35  meimon
; Pi->DPi
;
; Revision 1.2  2006/10/31 18:23:30  meimon
; castage en double
;
; Revision 1.1  2006/10/31 13:15:11  meimon
; Initial revision
;-

FUNCTION WISARD_OIFITS2DATA, filename, HELP = help, VERSION = version
on_error,2
IF keyword_set(version) THEN $
    printf, -2, '% '+routine_courante()+': $Revision: 1.7 $, $Date: 2007/01/29 16:48:36 $'

IF (n_params() NE 1) OR keyword_set(help) THEN BEGIN ;(fill-in from syntax)
   message, 'Help required or incorrect syntax. Documentation:', /INFO
   doc_library, routine_courante()
   retall
ENDIF
n_file = n_elements(filename)
;%%%%%%%%%%%%%%%%%%%%%%%boucle for %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
FOR j = 0, n_file-1 DO BEGIN
   ifilename = filename[j]

;cration des fichiers oivis1, oivis2, oit3
   READ_OIDATA, ifilename, oiarray,oitarget,oiwavelength,$
                oivis, oivis2,oit3 ;, /inventory
   lambda=*oiwavelength[0].eff_wave
   n_lambda = n_elements(lambda)
   IF n_lambda NE 1L THEN BEGIN
      print, 'Erreur: plusieur longueurs d''onde dans le fichier', ifilename
      retall
   ENDIF
   
;     retall
;     ENDIF
                              ;stop
   
                              ;rordonnons tous les champs par instant de
                              ;mesure croissant et par ordre lexico sur les
                              ;indices de tels
   ramp = indgen(n_elements(oit3.time))+10000
   insname_time=nbr2str(oit3.time[*])+ nbr2str((oit3.sta_index)[0,*])+ $
                nbr2str((oit3.sta_index)[1,*])+ nbr2str((oit3.sta_index)[2,*])+ nbr2str(ramp[*])
   time_table = sort(insname_time)
   n_t3time = n_elements(time_table)
   oit3.insname = (oit3.insname)[time_table]
   oit3t3amp = dblarr(n_t3time, n_lambda)+0D
   oit3t3amperr = dblarr(n_t3time, n_lambda)+0D ;0*time_table+0D
   oit3t3phi = dblarr(n_t3time, n_lambda)+0D ;0*time_table+0D
   oit3t3phierr = dblarr(n_t3time, n_lambda)+0D ;0*time_table+0D
   oit3.sta_index = (oit3.sta_index)[*, [time_table]]
   FOR i = 0, n_elements(time_table)-1 DO BEGIN 
      oit3t3amp[i, *] = (*oit3[time_table[i]].t3amp)
      oit3t3amperr[i, *] = (*oit3[time_table[i]].t3amperr)
      oit3t3phi[i, *] = (*oit3[time_table[i]].t3phi)
      oit3t3phierr[i, *] = (*oit3[time_table[i]].t3phierr)
   ENDFOR
   indl = 0 
   clotures = reform(oit3t3phi, n_elements(oit3t3phi))
                              ;stop
   sigma_clotures = reform(oit3t3phierr, n_elements(oit3t3phierr))
   oit3.u1coord = (oit3.u1coord)[time_table]
   oit3.u2coord = (oit3.u2coord)[time_table]
   oit3.v1coord = (oit3.v1coord)[time_table]
   oit3.v2coord = (oit3.v2coord)[time_table]
   u3coord = oit3.u1coord+oit3.u2coord
   v3coord = oit3.v1coord+oit3.v2coord
                              ;oit3.u1coord=u(AB)
                              ;oit3.v1coord=v(AB)
                              ;oit3.u2coord=u(BC)
                              ;oit3.v2coord=v(BC)
                              ; u3coord = u(AC)
                              ; v3coord = v(AC)
                              ;modif freqs
                              ;stop
   
   
    ;;;;;;;;;;;;;;;calcul omega, mat_aber, etc... ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
   
   IF keyword_set(oiarray) THEN n_tels = n_elements(oiarray.arrname) ELSE $
       n_tels = max(oivis2.sta_index)+1
   n_triplets = n_elements(oit3.t3amp)
   n_nuplets = 2*n_elements(oit3.time)/((n_tels-1)*(n_tels-2))
   n_triplets_par_nuplet = n_triplets/n_nuplets
   
   
   
    ;;;;;;;;;;;;;;;;;;;depouillement modules ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
                              ;%%%%%%%%%un seul lambda%%%%%%%%%%%%%%%%%
   indl = 0
   ramp2 = indgen(n_elements(oivis2.time))+10000
   insname_time2=nbr2str(oivis2.time[*])+nbr2str((oivis2.sta_index)[0,*])+nbr2str((oivis2.sta_index)[1,*])+nbr2str(ramp2[*])
   time_table2 = sort(insname_time2)
   oivis2_freqc = oivis2[time_table2].ucoord+!dI*oivis2[time_table2].vcoord
                              ;%trouver LE bon lambda
   insname_tab = oivis2[time_table2].insname
   tab_lambda = dblarr(n_elements(time_table2))
   FOR i = 0, n_elements(insname_tab)-1 DO BEGIN 
      ins = insname_tab[i]
      insind = where(oiwavelength.insname EQ ins)
      tab_lambda[i] = lambda[indl, insind]
   ENDFOR
                              ;%trouver LE bon lambda
                              ;stop
   freqc = oivis2_freqc/tab_lambda
   
   vis2 = 0D*time_table2
   sigmod = 0D*time_table2
   sigma_vis2 = 0D*time_table2
   FOR i = 0, n_elements(time_table2)-1 DO BEGIN 
      vis2[i] = (*oivis2[time_table2[i]].vis2data)[indl]
      IF keyword_set(wideband) THEN sig_s = $
          (*oivis2[time_table2[i]].vis2err)[indl]+1.2e-2 ELSE sig_s = $
          (*oivis2[time_table2[i]].vis2err)[indl]
      sigma_vis2[i] = sig_s
   ENDFOR
   
   
                              ;vis = sqrt((vis2) > 0)
   sigma_clotures = !DPi/180.*sigma_clotures
   clotures = !DPi/180.*clotures
   
   
   
   fmax = max(abs(freqc))
   fmin = min(abs(freqc))
   
   n_nuplets = n_elements(clotures)/(n_triplets_par_nuplet)
   n_bases = n_elements(vis2)
   n_bases_par_nuplet = n_bases/n_nuplets
   n_clotures_par_nuplet = n_elements(clotures)/n_nuplets
   raw_idata = {vis2:vis2*1D, sigma_vis2:sigma_vis2*1D,sigma_clotures:sigma_clotures*1D, $
               clotures:clotures*1D, n_nuplets:n_nuplets, $
               n_bases_par_nuplet:n_bases_par_nuplet, $
               n_clotures_par_nuplet:n_clotures_par_nuplet, n_tels:n_tels, $
               freqs_u:real(freqc)*1D, freqs_v:imaginary(freqc)*1D}
;;;transformation en idata
   idata = replicate({vis2:dblarr(raw_idata.n_bases_par_nuplet), vis2err:dblarr(raw_idata.n_bases_par_nuplet), $
                     clot:dblarr(raw_idata.n_clotures_par_nuplet), cloterr:dblarr(raw_idata.n_clotures_par_nuplet), $
                     freqs_u:dblarr(n_tels-1),freqs_v:dblarr(n_tels-1) }, $
                    raw_idata.n_nuplets)
   idata.vis2 = reform(raw_idata.vis2, raw_idata.n_bases_par_nuplet, raw_idata.n_nuplets)
   idata.vis2err = reform(raw_idata.sigma_vis2, raw_idata.n_bases_par_nuplet, raw_idata.n_nuplets)
   idata.clot = reform(raw_idata.clotures, raw_idata.n_clotures_par_nuplet, raw_idata.n_nuplets)
   idata.cloterr = reform(raw_idata.sigma_clotures, raw_idata.n_clotures_par_nuplet, $
                         raw_idata.n_nuplets)
   idata.freqs_u =  (reform(raw_idata.freqs_u, raw_idata.n_bases_par_nuplet, $
                           raw_idata.n_nuplets))[0:raw_idata.n_tels-2, *]
   idata.freqs_v =  (reform(raw_idata.freqs_v, raw_idata.n_bases_par_nuplet, $
                           raw_idata.n_nuplets))[0:raw_idata.n_tels-2, *]
   
   
   
   IF j EQ 0 THEN data = idata ELSE  data = [data, idata]
ENDFOR

return, data
END


filename = '~/idl/BIC/PHASE1/final1.oifits'
data = wisard_oifits2data(filename)
END

