;+
;NOM :
;	CODE - informations (type en clair, nb d'octets) sur les variables IDL
;
;CATEGORIE :
;	HELP ROUTINES
;
;SYNTAXE :
;	CODE(A[,NAME=name,TYPE=type,/GET_NAME,/GET_NUMBER,/GET_SIZE,/UNDEF,/BYTE,
;		/INT,/LONG,/FLOAT,/DOUBLE,/COMPLEX,/STRING,/STRUCT,/DCOMPLEX,/POINTER,
;		/OBJREF])
;
;DESCRIPTION :
;	CODE(A) retourne le numero de codage (ou le nom, ou la taille)
;	correspondant au type de la variable 'A' ou des elements de 'A' si c'est
;	un tableau ou les noms d'une structure.
;	A		 : variable IMSL/IDL dont il faut determiner le codage
;
;	Les noms de type en minuscule sont valables (en sortie ils sont en
;	majuscules). La table de correspondance des type, noms, codes et tailles
;	est:
;
;				 TYPE				   NAME		  TYPE	   SIZE
;		------------------------    ---------    ------    ----
;		                             'UNDEF'        0        -
;		 8-bit unsigned integer       'BYTE'        1        1
;		 16-bits signed integer       'INT'         2        2
;		 32-bits signed integer       'LONG'        3        4
;		 32-bits floating point      'FLOAT'        4        4
;		 64-bits floating point      'DOUBLE'       5        8
;		2x32-bits floating point    'COMPLEX'       6        8
;		      text string            'STRING'       7        -
;		                             'STRUCT'       8        -
;		2x64-bits floating point    'DCOMPLEX'      9        16
;		                            'POINTER'       10       -
;		                             'OBJREF'       11       -
;
;	Au moins une des entrees optionnelles doit etre specifiee, mais si
;	plusieurs sont specifiees, seule la premiere de la liste est prise
;	en compte.
;
;	OPTIONS D'ENTREE :
;
;	NAME=name	- Chaine de caractere qui contient le nom du codage.
;	TYPE=type	- Type (i.e. numero) du codage.
;	/UNDEF		- Le codage est UNDEF.
;	/BYTE		- Le codage est BYTE.
;	/INT		- Le codage est INT.
;	/LONG		- Le codage est LONG.
;	/FLOAT		- Le codage est FLOAT.
;	/DOUBLE		- Le codage est DOUBLE.
;	/COMPLEX	- Le codage est COMPLEX.
;	/STRING		- Le codage est STRING.
;	/STRUCT		- Le codage est STRUCT.
;	/DCOMPLEX	- Le codage est DCOMPLEX.
;	/POINTER	- Le codage est POINTER.
;	/OBJREF		- Le codage est OBJREF.
;
;	OPTIONS DE SORTIE :
;
;	/GET_NAME	- Retourne le nom du codage.
;	/GET_TYPE	- Retourne le type (i.e. numero) du codage (par defaut).
;	/GET_SIZE	- Retourne le nombre d'octet(s) du codage.
;
;DIAGNOSTIC D'ERREUR :
;
;
;VOIR AUSSI :
;
;
;HISTORIQUE :
;	version 1.0: 01/10/1992 - Eric THIEBAUT
;	version 1.1: 01/10/1995 - Luc BONDANT : ajout de STRUCT et DCOMPLEX
;	version 1.2: 03/04/1997 - Luc BONDANT : ajout de STRING
;	version 2.0: 17/03/1998 - Luc BONDANT : ajout de UNDEF, POINTER et OBJREF
;   Version 2.1: 30/05/2000 - Frederic Cassaing: conversion tab() en tab[]
;
;   Pour les "nouveaux" types (>11) code ne gere que la taille (nb octets)
;   Pour avoir le nom d'un type, utiliser la fonction IDL "size(/tname)"
;   Cette routine code sera a court terme obsolete.
;
;-
FUNCTION code,var,NAME=name,TYPE=type,UNDEF=ud,BYTE=i1,INT=i2,LONG=i4, $
	FLOAT=r4,DOUBLE=r8,COMPLEX=c4,STRING=st,STRUCT=str,DCOMPLEX=c8, $
	POINTER=pt,OBJREF=ob,GET_NAME=get_name,GET_TYPE=get_type,GET_SIZE=get_size

on_error,2
get_name=keyword_set(get_name)
get_type=keyword_set(get_type)
get_size=keyword_set(get_size)
IF get_name AND get_type THEN $
	message,'ERROR - Incompatible keywords GET_NAME and GET_TYPE'
IF get_name AND get_size THEN $
	message,'ERROR - Incompatible keywords GET_NAME and GET_SIZE'
IF get_type AND get_size THEN $
	message,'ERROR - Incompatible keywords GET_TYPE and GET_SIZE'

IF n_params() EQ 1 THEN BEGIN
	s=size(var)
	type=s[s[0]+1]
;	IF type EQ 0 THEN message,'ERROR - VAR undefined'
END ELSE IF keyword_set(name) THEN BEGIN
	s=size(name)
	IF s[s[0]+1] NE 7 THEN $
		message,'ERROR - NAME must be a string'
	CASE strupcase(name) OF
		'UNDEF'		: type=0
		'BYTE'		: type=1
		'INT'		: type=2
		'LONG'		: type=3
		'FLOAT'		: type=4
		'DOUBLE'	: type=5
		'COMPLEX'	: type=6
		'STRING'	: type=7
		'STRUCT'	: type=8
		'DCOMPLEX'	: type=9
		'POINTER'	: type=10
		'OBJREF'	: type=11
		ELSE		: message,'ERROR - NAME invalid'
	END
END ELSE IF keyword_set(type) THEN BEGIN
	IF type LT 0 OR type GT 11 THEN message,'ERROR - TYPE invalid'
END ELSE BEGIN
	IF keyword_set(ud) THEN type=0 ELSE $
	IF keyword_set(i1) THEN type=1 ELSE $
	IF keyword_set(i2) THEN type=2 ELSE $
	IF keyword_set(i4) THEN type=3 ELSE $
	IF keyword_set(r4) THEN type=4 ELSE $
	IF keyword_set(r8) THEN type=5 ELSE $
	IF keyword_set(c4) THEN type=6 ELSE $
	IF keyword_set(st) THEN type=7 ELSE $
	IF keyword_set(str) THEN type=8 ELSE $
	IF keyword_set(c8) THEN type=9 ELSE $
	IF keyword_set(pt) THEN type=10 ELSE $
	IF keyword_set(ob) THEN type=11 ELSE $
		message,'SYNTAX - CODE(VAR[,NAME=name,TYPE=type,/GET_NAME,'+ $
		'/GET_NUMBER,/GET_SIZE,/UNDEF,/BYTE,/INT,/LONG,/FLOAT,/DOUBLE,'+ $
		'/COMPLEX,/STRING,/STRUCT,/DCOMPLEX,/POINTER,/OBJREF])'
END

; retourne le nom du code, le nombre d'octets du code ou le numero du code
IF get_name THEN BEGIN
	CASE type OF
		0	: return,'UNDEF'
		1	: return,'BYTE'
		2	: return,'INT'
		3	: return,'LONG'
		4	: return,'FLOAT'
		5	: return,'DOUBLE'
		6	: return,'COMPLEX'
		7	: return,'STRING'
		8	: return,'STRUCT'
		9	: return,'DCOMPLEX'
		10	: return,'POINTER'
		11	: return,'OBJREF'
	END
END ELSE IF get_size THEN BEGIN
	CASE type OF
		0	: message,'ERROR - No size for UNDEF'
		1	: return,1L
		2	: return,2L
		3	: return,4L
		4	: return,4L
		5	: return,8L
		6	: return,8L
		7	: message,'ERROR - No size for STRING'
		8	: message,'ERROR - No size for STRUCT'
		9	: return,16L
		10	: message,'ERROR - No size for POINTER'
        11	: message,'ERROR - No size for OBJREF'
        12  : return, 2       ; Unsigned Integer
        13  : return, 4       ; ULONG' Unsigned Longword Integer
        14  : return, 8       ; LONG64'    64-bit Integer
        15  : return, 8       ; ULONG64'      Unsigned 64-bit Integer
	END
END ELSE BEGIN
		CASE type OF
		0	: return,0
		1	: return,1
		2	: return,2
		3	: return,3
		4	: return,4
		5	: return,5
		6	: return,6
		7	: return,7
		8	: return,8
		9	: return,9
		10	: return,10
		11	: return,11
	END
END

message,'BUG - !?!'

END
