; $Id: whereis.pro,v 1.5 2007/01/26 11:24:41 mugnier Exp $
; Copyright (c) L. Mugnier, ONERA, 2007.
;
; This software is copyright ONERA.
; The author is Laurent Mugnier.
; E-mail: mugnier at onera.fr
;
; This software is a computer program whose purpose is to find an IDL program.
;
; This software is governed by the CeCILL-C license under French law and
; abiding by the rules of distribution of free software. You can use, modify
; and/ or redistribute the software under the terms of the CeCILL-C license as
; circulated by CEA, CNRS and INRIA at the following URL
; "http://www.cecill.info".
;
; As a counterpart to the access to the source code and  rights to copy,
; modify and redistribute granted by the license, users are provided only
; with a limited warranty  and the software's author,  the holder of the
; economic rights,  and the successive licensors  have only  limited
; liability. 
;
; In this respect, the user's attention is drawn to the risks associated
; with loading,  using,  modifying and/or developing or reproducing the
; software by the user in light of its specific status of free software,
; that may mean  that it is complicated to manipulate,  and  that  also
; therefore means  that it is reserved for developers  and  experienced
; professionals having in-depth computer knowledge. Users are therefore
; encouraged to load and test the software's suitability as regards their
; requirements in conditions enabling the security of their systems and/or 
; data to be ensured and,  more generally, to use and operate it in the 
; same conditions as regards security. 
;
; The fact that you are presently reading this means that you have had
; knowledge of the CeCILL-C license and that you accept its terms.
;

PRO WHEREIS, routine, result, NOSUFFIX = nosuffix, QUIET = quiet, $
             VERSION = version, HELP = help
;+
;NOM :
;   WHEREIS - Trouve l'emplacement d'un programme IDL.
;   
;CATEGORIE :
;   Help Routines
;
;SYNTAXE :
;   WHEREIS, routine [, result] [, /NOSUFFIX] [, /QUIET] [, /VERSION] [, /HELP]
;
;DESCRIPTION :
;   La procdure WHEREIS recherche une routine (procdure ou fonction) dans le
;   chemin courant (runion du rpertoire courant ./ et de !PATH), et affiche
;   son nom complet (rpertoire + nom de fichier).
;
;   Limitation : WHEREIS ne marche que sous Unix (utilise le shell sh et la
;                commande ls)
;   
;   ARGUMENTS :
;   routine  : (entre) chane de caractres contenant la routine  rechercher
;
;   result   : (sortie) nom de variable optionnel, qui contient en sortie le
;              nom complet de la routine (rpertoire + nom de fichier), ou ''
;              si celle-ci est introuvable.
;
;   /NOSUFFIX: (entre) si ce mot-cl est prsent et non nul, on recherche
;              le nom de fichier exact 'routine' sans ajouter le suffixe
;              '.pro' (utile pour trouver par exemple des librairies .so).
;
;   /QUIET   : (entre) n'affiche pas le nom complet de la routine. Utile
;              uniquement en conjonction avec l'argument result.
;
;   /VERSION : (entre) affichage de la version avant l'excution.
;   
;   /HELP    : (entre) affichage de la syntaxe et sortie du programme.
;
;VOIR AUSSI :
;   ROUTINE_INFO
;
;AUTEUR :
;   $Author: mugnier $
;
;HISTORIQUE :
;   $Log: whereis.pro,v $
;   Revision 1.5  2007/01/26 11:24:41  mugnier
;   Ajout copyright et licence CeCILL-C.
;
;   Revision 1.4  2003/04/16 17:31:11  mugnier
;   Mot-cl /QUIET ajout.
;
;   Revision 1.3  2003/04/15 09:18:02  mugnier
;   Mot-cl /NOSUFFIX pour chercher des fichiers autres que .pro.
;
;   Revision 1.2  2001-05-18 12:25:34+02  mugnier
;   Remplacement de str_sep(), obsolete depuis IDL 5.3, par strsplit.
;
;   Revision 1.1  1999-04-26 10:55:20+02  mugnier
;   Initial revision
;
;-

on_error,2
IF keyword_set(version) THEN $
    message, '$Revision: 1.5 $, $Date: 2007/01/26 11:24:41 $', /INFO 

IF (n_params() LT 1) OR (n_params() GT 2) OR keyword_set(help) THEN $
    message, 'Usage : WHEREIS, routine [, result] [, /NOSUFFIX] [, /QUIET] [, /VERSION] [, /HELP]'


IF (!VERSION.OS_FAMILY NE 'unix') THEN $
    message, 'this routine only works on Unix-like systems'

IF keyword_set(nosuffix) THEN suffix = '' ELSE suffix = '.pro'

subdirs = strsplit('.:'+!PATH, ':', /EXTRACT); recherche dans . et dans !PATH
pathfiles= ''
FOR i = 0, (n_elements(subdirs)-1) DO BEGIN
    pathfile = subdirs[i] + '/' + routine + suffix ; chemin+nom_fichier
    pathfiles= pathfiles+ ' ' + pathfile           ; et on concatne
ENDFOR

;; on lance ls en redirigeant uniquement l'erreur standard (i.e. les fichiers
;; non trouvs) sur /dev/null. La sortie standard (fichiers trouvs) -> result

spawn, /SH, 'ls ' + pathfiles + ' 2>/dev/null', result

;; une autre possibilit : par find -maxdepth 1 -follow. Mais attention :
;; le flag '-maxdepth 1' est reconnu SEULEMENT par le find de GNU.

IF NOT keyword_set(quiet) THEN print, result

END

;; ALTERNATIVE : TENTATIVE DE TROUVER UNE ROUTINE DEPUIS IDL :
;; ne marche pas car RESOLVE_ROUTINE est pnible (on doit lui prciser
;; /is_function ou non)        
; message,/reset
; CATCH, Error_status
; ;stop
; RESOLVE_ROUTINE, routine
; print, 'Statut erreur :', Error_status
; error_code = !ERROR_STATE.code
; CATCH, /cancel

; IF (error_code NE 0L) THEN BEGIN ; not a user procedure
;     RESOLVE_ROUTINE, routine, /is_function
;     error_code = !ERROR_STATE.code
;     IF (error_code NE 0L) THEN BEGIN ; not a user function
;         message, routine+' is not a user function or procedure.', /INFO
;     ENDIF ELSE BEGIN 
;         result = (ROUTINE_INFO(routine, /source, /functions)).path
;     ENDELSE
; ENDIF ELSE BEGIN
;     result = (ROUTINE_INFO(routine, /source)).path
; ENDELSE

