; $Id: wisard_jdata_x.pro,v 1.5 2007/01/29 10:38:29 meimon Exp $ 
; This file is part of the WISARD software.
;
; Copyright (c) S. Meimon and L. Mugnier, ONERA, 2004-2007.
;
; This software, WISARD, is made of wisard.pro and all the wisard_*.pro files
; under the same directory, as well as the example batch file wisard_batch.pro
; 
; This software is copyright ONERA.
; The authors are Serge Meimon and Laurent Mugnier.
; E-mail: meimon at onera.fr and mugnier at onera.fr
;
; This software is a computer program whose purpose is to reconstruct an image
; of an observed object from a set of interferometric measurements.
;
; This software is governed by the CeCILL-B license under French law and
; abiding by the rules of distribution of free software. You can use, modify
; and/ or redistribute the software under the terms of the CeCILL-B license as
; circulated by CEA, CNRS and INRIA at the following URL
; "http://www.cecill.info".
;
; As a counterpart to the access to the source code and  rights to copy,
; modify and redistribute granted by the license, users are provided only
; with a limited warranty  and the software's author,  the holder of the
; economic rights,  and the successive licensors  have only  limited
; liability. 
;
; In this respect, the user's attention is drawn to the risks associated
; with loading,  using,  modifying and/or developing or reproducing the
; software by the user in light of its specific status of free software,
; that may mean  that it is complicated to manipulate,  and  that  also
; therefore means  that it is reserved for developers  and  experienced
; professionals having in-depth computer knowledge. Users are therefore
; encouraged to load and test the software's suitability as regards their
; requirements in conditions enabling the security of their systems and/or 
; data to be ensured and,  more generally, to use and operate it in the 
; same conditions as regards security. 
;
; The fact that you are presently reading this means that you have had
; knowledge of the CeCILL-B license and that you accept its terms.
;
; Additionally, if you use this code or a code derived from it (e.g., for a
; publication), please cite the following papers, on which it is based:
;   
; (1) S. Meimon, L. M. Mugnier, and G. Le Besnerais,
;   "Reconstruction method for weak-phase optical interferometry", 
;   Opt. Lett., 30(14):1809-1811, July 2005.
;   PDF is on-line at: http://laurent.mugnier.free.fr/publis/Meimon-OL-05.pdf
; (2) S. Meimon, L. M. Mugnier, and Guy Le Besnerais,
;   "A convex approximation of the likelihood in optical interferometry",
;   J. Opt. Soc. Am. A, November 2005.
;   PDF is on-line at: http://laurent.mugnier.free.fr/publis/Meimon-JOSAA-05.pdf
;

;+
; NAME:
;   WISARD_JDATA_X - Generalised Mean square complex data likelihood
;                    Criterion for WISARD
;
; CATEGORY:
;	Array and Image Processing Routines 
;
; CALLING SEQUENCE:
;   value = WISARD_JDATA_X ( x, RE_PH = re_ph, IM_PH = im_ph
;                            , RE_Y_DATA = re_y_data, IM_Y_DATA = im_y_data 
;                            , W11 = w11, W12 = w12, W11 = w22
;                           [,GRADIENT_X=gradient_x] [, /VERSION] [, /HELP])
;
;
; PURPOSE:
;   This function computes and returns the value of the data likelihood
;   criterion of WISARD. Its gradient w.r.t. the object is
;   optionnally computed.
;
;
; POSITIONAL PARAMETERS:
;   x             : (input) 1D object for which we want to compute the value
;                   of the criterion.
;	
; KEYWORD PARAMETERS:
;   GRADIENT_X    : (optional input/output) if set and not equal to zero, contains in
;                    output the gradient w.r.t. to the object.
;   RE_PH         : (input) real part of matrix diag(exp i bbar alpha)#H
;   IM_PH         : (input) imaginary part of matrix diag(exp i bbar alpha)#H
;  
;   RE_Y_DATA     : (input) real part of data
;   IM_Y_DATA     : (input) imaginary part of data
;  
;   W11,W12,W22   : (inputs) see doc scientifique
;
;   /VERSION : (optional input) prints version number before execution.
;   
;   /HELP    : (optional input) prints the documentation and exits.
;
;
; AUTHORS:
; Serge Meimon and Laurent Mugnier (ONERA). 
; Contact: lastname at onera.fr
;
;
; RESTRICTIONS:
;   This code is copyright (c) S. Meimon and L. Mugnier, ONERA, 2004-2007. 
;   
;   WISARD is governed by the CeCILL-B license under French law and abiding by
;   the rules of distribution of free software. You can use, modify and/ or
;   redistribute the software under the terms of the CeCILL-B license as
;   circulated by CEA, CNRS and INRIA at the following URL:
;   "http://www.cecill.info".
;   See source code for the full notice.
;
;   Additionally, if you use this code or a code derived from it (e.g., for a
;   publication), please cite the following papers, on which it is based:
;   
;   (1) S. Meimon, L. M. Mugnier, and G. Le Besnerais,
;   "Reconstruction method for weak-phase optical interferometry", 
;   Opt. Lett., 30(14):1809-1811, July 2005.
;   PDF is on-line at: http://laurent.mugnier.free.fr/publis/Meimon-OL-05.pdf
;   (2) S. Meimon, L. M. Mugnier, and Guy Le Besnerais,
;   "A convex approximation of the likelihood in optical interferometry",
;   J. Opt. Soc. Am. A, November 2005.
;   PDF is on-line at: http://laurent.mugnier.free.fr/publis/Meimon-JOSAA-05.pdf
;
; EXAMPLE:
;	Please provide a simple example here. 
;
; SEE ALSO:
;   All the WISARD_*.pro files, which are part of WISARD and covered by the
;   same copyright and license.
;   
; HISTORY:
;   $Log: wisard_jdata_x.pro,v $
;   Revision 1.5  2007/01/29 10:38:29  meimon
;   *** empty log message ***
;
;   Revision 1.4  2006/10/31 18:27:38  meimon
;   cast en double, grad_diff_fini OK
;
;   Revision 1.3  2006/10/27 18:28:21  meimon
;   Syntaxe renseigne, compile
;
;   Revision 1.2  2006/10/27 17:37:08  meimon
;   *** empty log message ***
;
;   Revision 1.1  2006/10/27 17:13:03  meimon
;   Initial revision
;   
;-

FUNCTION  WISARD_JDATA_X, x, OPERATORS = operators, RE_PH = re_ph, IM_PH = im_ph, $
                          RE_Y_DATA = re_y_data, IM_Y_DATA = im_y_data, $
                          W11 = w11, W12 = w12, W22 = w22, $
                          GRADIENT_X=gradient_x, $
                          VERSION = version, HELP = help


;; put the following 9 lines (down to 1st ENDIF) just after routine name:
on_error,2
IF keyword_set(version) THEN $
    printf, -2, '% '+routine_courante()+': $Revision: 1.5 $, $Date: 2007/01/29 10:38:29 $'

IF (n_params() NE 1) OR keyword_set(help) THEN BEGIN ;(fill-in from syntax)
    message, 'Help required or incorrect syntax. Documentation:', /INFO
    doc_library, routine_courante()
    retall
ENDIF




;recastage en vecteurs compatibles avec la taille de H
;print, 'debut recast'
vect_re_y_data = reform(re_y_data,(size(re_ph))[1])
vect_im_y_data = reform(im_y_data,(size(re_ph))[1])
vect_w11 = reform(w11,(size(re_ph))[1])
vect_w12 = reform(w12,(size(re_ph))[1])
vect_w22 = reform(w22,(size(re_ph))[1])
;print, 'fin recast'
;calcul des rsidus
re_y_res = vect_re_y_data-re_ph#x
im_y_res = vect_im_y_data-im_ph#x

;; calcul du gradient
; si gradient est une variable dfinie et non nulle (par exemple 1) :
IF keyword_set(gradient_x) THEN BEGIN 
   gradient_x_1 = -transpose(re_ph)#(vect_w11*re_y_res+vect_w12*im_y_res)
   gradient_x_2 = -transpose(im_ph)#(vect_w12*re_y_res+vect_w22*im_y_res)
   gradient_x = gradient_x_1+gradient_x_2
ENDIF


return, total(.5*vect_w11*abs2(re_y_res)+.5*vect_w22*abs2(im_y_res)+vect_w12*re_y_res*im_y_res)

END
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;%%%%%%%cration des donnes et de l'objet courant
filename = '~/idl/BIC/PHASE1/final1.oifits'
data = wisard_oifits2data(filename)
unemas = 1d-3*(!DPi/180D)/3600D ; une mas en rd
fov = 12.*unemas
;seed = 1
;ndat = 1000
; data0 = {vis2:abs(randomn(seed, 15))*10., vis2err:abs(randomn(seed, 15)), clot:randomn(seed,10), $
;          cloterr:abs(randomn(seed, 10)), freqs_u:abs(randomn(seed, 5))+1., freqs_v:abs(randomn(seed, 5))+1.}
; data=replicate(data0,ndat)


mdata = WISARD_DATA2MDATA(data, OPERATORS = operators)
cmdata = WISARD_MDATA2CMDATA(mdata, OPERATORS = operators)
H=wisard_make_h(FREQS_U=reform(cmdata.freqs_u, operators.n_bases*n_elements(mdata)),$ 
                FREQS_V=reform(cmdata.freqs_v, operators.n_bases*n_elements(mdata)), $
                FOV = fov, np_min = 32)
H = H*1e10; pour le calcul de grad_num
npix = (size(H))[2]
sqnpix = sqrt(npix)
TH = conj(transpose(H))
dirty_map = TH#reform(cmdata.vis,(size(H))[1])
xdm = real(dirty_map) >0
aff, rotate(reform(xdm, sqnpix, sqnpix),5)

re_ph = real(H)
im_ph = imaginary(H)
re_y_data = real(cmdata.vis)
im_y_data = imaginary(cmdata.vis)
abs_y_data = abs(cmdata.vis)
arg_y_data = angle(cmdata.vis)

w11 = cmdata.w_rad*abs2(COS(arg_y_data)) $
      +cmdata.w_tan*abs2(SIN(arg_y_data))
w12 = cmdata.w_tan*abs2(COS(arg_y_data)) $
      +cmdata.w_rad*abs2(SIN(arg_y_data))
w22 = (cmdata.w_rad-cmdata.w_tan)*COS(arg_y_data)*SIN(arg_y_data)
;%%%%%%%
gradient = 1
dummy = WISARD_JDATA_X(xdm , RE_PH = re_ph, IM_PH = im_ph, RE_Y_DATA = $
re_y_data, IM_Y_DATA = im_y_data, W11 = w11, W12 = w12, W22 = w22, $
           gradient_x=gradient)
epsilon =.0001D

gradnum=grad_diff_finies('wisard_jdata_x',xdm,RE_PH = re_ph, IM_PH = im_ph, $
                         RE_Y_DATA = $
re_y_data, IM_Y_DATA = im_y_data, W11 = w11, W12 = w12, W22 = w22, epsilon = epsilon)
print, 'Corrlation entre les 2 gradients :', correlate(gradient,gradnum)
print, 'Rapport d''chelle :', stddev(gradient)/stddev(gradnum)

info, gradient-gradnum
info, gradient

END
