; $Id: wisard_batch.pro,v 1.5 2007/02/06 09:17:11 mugnier Exp $

;; RUN THIS EXAMPLE FROM THE "pro/" DIRECTORY
print, 'This is the WISARD demo, to be run from the ''pro/'' directory'

;; Add the libraries needed by WISARD to IDL's search PATH:
!PATH = expand_path('+../lib') + ':' + !PATH 

;; Enable use of LUTs (a.k.a. "color tables" in IDL jargon):
device, decomposed=0

;; Accept license:
dummy = wisard(/copyright)

;; Preprocessing of data file -> suitable data format
!PATH = expand_path('+../lib') + ':' + !PATH 
defsysv, '!DI', dcomplex(0, 1), 1;Define i; i^2=-1 as readonly system-variable
datafilename = '../inputdata/dataImagingBeautyContest2004.oifits'
data = wisard_oifits2data(datafilename)

;; Reconstructed Field-Of-View and grid size:
NP_min = 32L
onemas = 1d-3*(!DPi/180D)/3600D ; one mas in radian
fov = 18.0*onemas

;; Convergence threshold:
threshold = 1d-06 

;; Initial guess for object:
guess = 0 ; no guess => dirty MAP used

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; RECONSTRUCTIONS:

;; For PSD regularization: set PSD (and DELTA=0)
;; The PSD of a disk-like object is ~ 1/f^3, with a
;; proportionality factor to be adjusted by hand.
distance = double(shift(dist(NP_min), NP_min/2, NP_min/2))
PSD = 1D/((distance^3  > 1D) < 1d6) 
;; For more regularization (to get a smoother object):
;; PSD /= 10D (or more) i.e. assume a weaker signal
;; For less regularization (to get an object with more details):
;; PSD *= 10D (or more) i.e. assume a stronger signal
x_psd = WISARD(data,  $
               FOV = fov, NP_MIN = np_min, $
               GUESS = guess, THRESHOLD = threshold, $
               PSD = psd, $ 
               AUX_OUTPUT = aux_output_psd, /DISPLAY)
;64/500. Convergence=3.63E-07. Criterion=193.4577 = 75.0564 + 118.4013
;81/500. Convergence=2.50E-08. Criterion=193.4508 = 75.0326 + 118.4181

;; Example of an under-regularized reconstruction:
x_psd_under = WISARD(data,  $
                  FOV = fov, NP_MIN = np_min, $
                  GUESS = guess, THRESHOLD = threshold, $
                  PSD = 100D*psd, $ 
                  AUX_OUTPUT = aux_output_psd_under, /DISPLAY)
;310/500. Convergence=8.27E-07. Criterion=63.1294 = 60.5661 + 2.5633


;; You may also want to look at a reconstruction without a regularization
;; (other than positivity). Convergence is very slow because of the absence of
;; regularization:
; x_unreg = WISARD(data,  $
;                   FOV = fov, NP_MIN = np_min, $
;                   GUESS = guess, $
;                   THRESHOLD = threshold, $
;                   PSD = 0D, MEAN_O = mean_o, $ 
;                      AUX_OUTPUT = aux_output_unreg, DISPLAY = 1B)
;;500/500. Convergence=2.60E-05. Criterion=58.7967 = 58.7967 + 0.0000



;; For L1-L2 regularization: set DELTA GT 0 (and PSD =0)
white = 1B;
scale = 1D/(NP_min)^2; for white L1-L2, scale ~ avg_object_level = 1/NP^2
delta = 1D; 

x_l1l2white = WISARD(data,  $
                  FOV = fov, NP_MIN = np_min, $
                  GUESS = 0, THRESHOLD = threshold, $
                  SCALE = scale, DELTA = delta, WHITE = white, $
                  AUX_OUTPUT = aux_output_l1l2white, /DISPLAY)
;113/500. Convergence=9.78E-07. Criterion=919.8711 = 66.4047 + 853.4664


;showlut,image=lut,/vert,zoom=1 
;ps_open, 'wisard_psdunder+psd+l1l2white.eps',xs=3*2.56,ys=2.56
window, 2, xs = 3*256, ys = 256 & wset, 2
gamma_ct, 0.7
aff,[rotate(x_psd_under, 5), rotate(x_psd, 5), rotate(x_l1l2white, 5)]
aff, lut[0:20,*],zoom=1
;ps_close


;; To obtain the same nice plots WISARD does during the minimization:
;ps_open, 'wisard_plot_fit.eps', /color
aux_output = aux_output_l1l2white
rad_freqs=aux_output.rad_freqs
abs_hx=aux_output.weights_x.abs_hx
abs_hx=reform(abs_hx,n_elements(abs_hx))
abs_y=aux_output.weights_constant.abs_y_data
abs_y=reform(abs_y,n_elements(abs_y))
inv_sigma_rad = reform(sqrt(aux_output.cmdata.w_rad),n_elements(abs_hx))
WISARD_PLOT_FIT,RAD_FREQS = rad_freqs, ABS_HX = abs_hx, ABS_Y = abs_y, $
            INV_SIGMA_RAD = inv_sigma_rad
;ps_close
